@@ -13,7 +13,10 @@
 
 #include <KAboutData>
 #include <KLocalizedString>
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
+#endif
 
 #include "kfinddlg.h"
 #include "kfind_version.h"
@@ -21,14 +24,18 @@
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kfind"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("kfindrc"));
     migrate.migrate();
+#endif
+
     KLocalizedString::setApplicationDomain("kfind");
 
     KAboutData aboutData(QStringLiteral("kfind"), i18n("KFind"),
                          QStringLiteral(KFIND_VERSION_STRING), i18n("KDE file find utility"), KAboutLicense::GPL,
-                         i18n("(c) 1998-2017, The KDE Developers"));
+                         i18n("(c) 1998-2021, The KDE Developers"));
 
     aboutData.addAuthor(i18n("Kai Uwe Broulik"), i18n("Current Maintainer"), QStringLiteral("kde@privat.broulik.de"));
     aboutData.addAuthor(i18n("Eric Coquelle"), i18n("Former Maintainer"), QStringLiteral("coquelle@caramail.com"));
@@ -47,9 +54,10 @@ int main(int argc, char **argv)
     aboutData.addAuthor(i18n("Alexander Neundorf"), QString(), QStringLiteral("neundorf@kde.org"));
     aboutData.addAuthor(i18n("Clarence Dang"), QString(), QStringLiteral("dang@kde.org"));
     aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     // enable high dpi support
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
+#endif
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
     parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("+[searchpath]"), i18n("Path(s) to search")));
